@@ -6,7 +6,7 @@ BEGIN {
   $Data::Handle::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Data::Handle::VERSION = '0.02001002';
+  $Data::Handle::VERSION = '0.02001003';
 }
 
 # ABSTRACT: A Very simple interface to the __DATA__  file handle.
@@ -19,7 +19,7 @@ my %datastash;
 use Symbol qw( gensym );
 use Scalar::Util qw( weaken );
 use parent qw( IO::File );
-use Package::Stash;
+use Package::Stash 0.15; # has_symbol
 use Carp ();
 use Data::Handle::Exception;
 use Data::Handle::IO;
@@ -62,8 +62,8 @@ sub _has_data_symbol {
   my $rval = undef;
   try {
     my $object = Package::Stash->new($package);
-    return unless $object->has_package_symbol('DATA');
-    my $fh = $object->get_package_symbol('DATA');
+    return unless $object->has_symbol('DATA');
+    my $fh = $object->get_symbol('DATA');
     $rval = defined fileno *{$fh};
   }
   catch {
@@ -84,7 +84,7 @@ sub _get_data_symbol {
       ->throw(
       '_get_data_symbol was called when there is no data_symbol to get');
   }
-  return Package::Stash->new($package)->get_package_symbol('DATA');
+  return Package::Stash->new($package)->get_symbol('DATA');
 }
 
 sub _get_start_offset {
@@ -284,8 +284,8 @@ sub _write {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -294,7 +294,7 @@ Data::Handle - A Very simple interface to the __DATA__  file handle.
 
 =head1 VERSION
 
-version 0.02001002
+version 0.02001003
 
 =head1 SYNOPSIS
 
@@ -393,10 +393,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
